.. _recipe_asr.push:

asr.push
========


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.push`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.push.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.push

or as a python module

.. code-block:: console

   $ python -m asr.push

Detailed description
--------------------
Push along phonon modes.

Steps
-----


asr.push
^^^^^^^^
.. autofunction:: asr.push.main
   